import json, datetime, requests
from flask import current_app
from elasticsearch8 import Elasticsearch

def config(k):
    with open(f'/configs/default/shared-data/{k}', 'r') as f:
        return f.read()

def main():
    #get the raw data by url
    traffic_url = "https://data-exchange-api.vicroads.vic.gov.au/bluetooth_data/sites"
    headers = {
        "Cache-Control": "no-cache",
        "Ocp-Apim-Subscription-Key": "257b936748224c4b84e8bad2af33ffbb"
    }
    response = requests.get(traffic_url, headers=headers)
    if response.status_code == 200:
        current_app.logger.info(f'Data retrieved successfully from API.')
        data = response.json()
        # processing the row data
        observations = []
        for obs in data:
            interval_start = obs["latest_stats"].get("interval_start")
            if interval_start:
                parsed_timestamp = datetime.datetime.fromisoformat(interval_start)
                formatted_timestamp = parsed_timestamp.strftime("%Y-%m-%d %H:%M:%S")
            else:
                formatted_timestamp = None
            observation = {
                "id": obs.get("id"),
                "number": obs.get("number"),
                "organization": {
                    "id": obs["organization"].get("id")
                },
                "enabled": obs.get("enabled"),
                "name": obs.get("name"),
                "location": obs.get("location"),
                "latest_stats": {
                    "interval_start": formatted_timestamp
                }
            }
            observations.append(observation)
         # exchange the result as JSON object
        data_up = {
            "observations": observations
        }
        # Connect to Elasticsearch
        # Get Elasticsearch username and password from environment variables
        es_username = config('ES_USERNAME')
        es_password = config('ES_PASSWORD')

        # Connect to Elasticsearch
        client = Elasticsearch(
            'https://elasticsearch-master.elastic.svc.cluster.local:9200',
            verify_certs=False,
            ssl_show_warn=False,
            basic_auth=(es_username, es_password)  # Use environment variables
        )

        # Log the data to be added to Elasticsearch
        current_app.logger.info(f'Sites Data to add to Elasticsearch: {data}')

        # Index the data into Elasticsearch
        res = client.index(
            index='sites',  # Replace with your index name
            body=data_up
        )
        # Log the result of indexing
        current_app.logger.info('Indexed data successfully')

        return 'ok'